#!/usr/bin/env python
import codecs
import os
from setuptools import find_packages, setup

BASE_DIR = os.path.abspath(os.path.dirname(__file__))


def read_file(filename):
    with codecs.open(os.path.join(BASE_DIR, filename), encoding='utf-8') as f:
        content = f.read()
    return content


README = read_file('README.md')
CHANGELOG = read_file('CHANGELOG.md')

setup(
    name='django-tinymce-lite',
    version='0.0.1',
    packages=find_packages(),
    include_package_data=True,
    author='Ivan Chernov',
    author_email='chernoffivan@gmail.com',
    description=('A Django application that contains a widget to render a '
                 'form field as a TinyMCE editor.'),
    long_description=README + '\n\n' + CHANGELOG,
    license='MIT License',
    keywords='django widget tinymce',
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    platforms=['any'],
    url='https://github.com/vanadium23/django-tinymce-lite',
    install_requires=[
        'django-appconf>=0.6.0',
    ],
    setup_requires=['pytest-runner'],
    tests_require=['pytest', 'mock', 'selenium', 'pytest-django', 'django'],
)
